from nonebot import on_command
from nonebot.matcher import Matcher
from nonebot.params import ArgPlainText, CommandArg
from nonebot.adapters.onebot.v11 import Message, MessageSegment, escape



wettr = on_command('天气', aliases={'wttr', 'weather', 'tianqi'})


@wettr.handle()
async def _handle(matcher: Matcher, city: Message = CommandArg()):
    if city.extract_plain_text() and city.extract_plain_text()[0]!='_':
        matcher.set_arg('city', city)


@wettr.got('city', prompt='你想查询哪个城市的天气呢？')
async def _(city: str = ArgPlainText('city')):
    if city[0]!='_':
        await wettr.send('少女观星中...', at_sender=True)
        await wettr.send(MessageSegment.image(file=f'http://zh.wttr.in/{escape(city)}.png', cache=False), at_sender=True)
    else:
        await wettr.reject_arg('city',prompt='不能使用“_”作为查询前缀！请重新输入！')



import setuptools
with open("README.md", "r",encoding="utf-8",errors="ignore") as fh:
    long_description = fh.read()

setuptools.setup(
    name="nonebot_plugin_weather_lite",
    version="0.0.1",
    author="zjkwdy",
    author_email="3377911508@qq.com",
    keywords=["pip", "nonebot2", "nonebot", "weather", "nonebot_plugin"],
    description="""使用wttr.in的天气查询 ，支持大部分wttr.in的用法。""",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/zjkwdy/nonebot_plugin_weather_lite",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
    platforms="any",
    install_requires=[
        "nonebot2 >= 2.0.0b1",
        "nonebot-adapter-onebot >= 2.0.0b1"
    ]
)